rm(list=ls())

library(tidyverse)
library(here)

#Read in temperature data
Temperature <- read_csv(here("Logger Data.csv"))

#Read in colony info
Colony.info <- read_csv(here("Colony info.csv"))

#Descriptive data for summary stats------------------------------------------------------------------------------------------

#Numbers of days per colony
Temperature%>%
  group_by(Colony, Date)%>%
  summarise(n. = length(Temperature)/length(Temperature))%>%
  group_by(Colony)%>%
  summarise(Days = sum(n.))%>%
  summarise(Mean = mean(Days),
            SD = sd(Days),
            n.= length(Days),
            se = SD/sqrt(n.))

#Temperature data
Temperature%>%
  mutate(Placement = replace(Placement, Placement !="External", "Internal"))%>%
  filter(Temperature !="")%>%
  group_by(Type, Placement)%>%
  summarise(Max = max(Temperature),
            Min = min(Temperature),
            Mean = mean(Temperature),
            SD = sd(Temperature),
            n.=length(Temperature),
            SE = SD/sqrt(n.))

#Temperature data
Temperature%>%
  filter(Placement !="External",
         Temperature !="")%>%
  group_by(Type, Placement)%>%
  summarise(Max = max(Temperature),
            Min = min(Temperature),
            Mean = mean(Temperature),
            SD = sd(Temperature),
            n.=length(Temperature),
            SE = SD/sqrt(n.))


#Colony information

#unique colonies 
length(unique(Colony.info$Colony)) #48 unique colonies



#Colony size and chamber dimensions
max(Colony.info$Size) #0102
min(Colony.info$Size) #10
mean(Colony.info$Size) #41.97
sd(Colony.info$Size) #17.08
17.08/sqrt(47)

Colony.height <- read_csv(here("Tree details.csv"))%>%
  select(Colony, ColonyHeight)%>%
  filter(ColonyHeight != "",
         ColonyHeight != "0")%>%
  summarise(Max = max(ColonyHeight),
            Min = min(ColonyHeight),
            Mean = mean(ColonyHeight),
            SD = sd(ColonyHeight))

tibble(Colony.height)

Chambers <- Colony.info%>%
  filter(Placement != "External")%>%
  group_by(Placement)%>%
  summarise(Distance.Mean = mean(Distance),
            Distance.SD = sd(Distance),
            Distance.n. = length(Distance),
            Distance.se = Distance.SD/sqrt(Distance.n.),
            Depth.Mean = mean(Depth),
            Depth.SD = sd(Depth),
            Depth.n. = length(Depth),
            Depth.se = Depth.SD/sqrt(Depth.n.))

length((unique(Colony.info$ChamberID)))

cor.test(Colony.info$Size, Colony.info$Distance)
cor.test(Colony.info$Size, Colony.info$Depth)
cor.test(Colony.info$Distance, Colony.info$Depth)

#Mean distance from the edge
tapply(Chambers$Distance, list(Colony.info$Placement), mean)
tapply(Chambers$Distance, list(Colony.info$Placement), sd)

#Mean depth of chamber
tapply(Chambers$Depth, list(Colony.info$Placement), mean)
tapply(Chambers$Depth, list(Colony.info$Placement), sd)

#Days above 40 and below 5
Critical <- Temperature%>%
  filter(Placement =="External",
         Temperature >= 40 | Temperature <= 5)%>%
  group_by(Type)%>%
  summarise(n. = length(unique(Date)))

#Split the data set to analyses the maximum and minimum temperatures separately and merge with colony info.  

Maximum <- Temperature%>%
  filter(Type =="Maximum")

Minimum <- Temperature%>%
  filter(Type =="Minimum")

#Merge colony in with maximum an minimum data
Maximum <- left_join(Maximum, Colony.info, by = c("Colony", "Period", "Placement"))
Minimum <- left_join(Minimum, Colony.info, by = c("Colony", "Period", "Placement"))


## Summary stats and Plots

ggplot(data = Maximum, aes(x=Placement, y=Temperature, color = Placement))+ 
  geom_boxplot()+
  facet_wrap(~Season)+
  ggtitle("Maximum")+
  theme(axis.text.x=element_blank(),
        axis.ticks.x=element_blank())

ggplot(data = Minimum, aes(x=Placement, y=Temperature, color = Placement))+ 
  geom_boxplot()+
  facet_wrap(~Season)+
  ggtitle("Minimum")+
  theme(axis.text.x=element_blank(),
        axis.ticks.x=element_blank())

#Check that we have chose the correct months for analyses as seasons.
#The tree hottest, for summer, the three coldest for winter and the correct Autum and spring months.

#External temp descriptive stats to help determine winter, summer, spring and autumn months
Max.Month <- Maximum%>%
  filter(Placement == "External",
          Temperature !="")%>%
  mutate(Month =format(Date,"%m"),
         Month = as.integer(Month))%>%
  group_by(Month)%>%
  summarise(Min = min(Temperature),
            Max = max(Temperature),
            Mean = mean(Temperature))%>%
  mutate(Season = ifelse(Month %in% 1, "January", ifelse(Month %in% 2, "February", 
                                                   ifelse(Month %in% 3, "March", 
                                                   ifelse(Month %in% 4, "April", 
                                                   ifelse(Month %in% 5, "May", 
                                                   ifelse(Month %in% 6, "June",
                                                   ifelse(Month %in% 7, "July", 
                                                   ifelse(Month %in% 8, "August", 
                                                   ifelse(Month %in% 9, "September",
                                                   ifelse(Month %in% 10, "October", 
                                                   ifelse(Month %in% 11, "November", "December"))))))))))))%>%
  arrange(Mean)
tibble(Max.Month)

#External temp descriptive stats to help determine hot, cold and inbetween temperatures
Min.Month <- Minimum%>%
  filter(Placement == "External",
         Temperature !="")%>%
  mutate(Month =format(Date,"%m"),
         Month = as.integer(Month))%>%
  group_by(Month)%>%
  summarise(Min = min(Temperature),
            Max = max(Temperature),
            Mean = mean(Temperature))%>%
  mutate(Season = ifelse(Month %in% 1, "January", ifelse(Month %in% 2, "February", 
                                                  ifelse(Month %in% 3, "March", 
                                                  ifelse(Month %in% 4, "April", 
                                                  ifelse(Month %in% 5, "May", 
                                                  ifelse(Month %in% 6, "June",
                                                  ifelse(Month %in% 7, "July", 
                                                  ifelse(Month %in% 8, "August", 
                                                  ifelse(Month %in% 9, "September",
                                                  ifelse(Month %in% 10, "October", 
                                                  ifelse(Month %in% 11, "November", "December"))))))))))))%>%
  arrange(Mean)


tibble(Min.Month)

Max.Seasons <- Maximum%>%
  filter(Temperature !="")%>%
  group_by(Season, Placement)%>%
  summarise(Min = min(Temperature),
            Max = max(Temperature),
            Mean = mean(Temperature),
            SD = sd(Temperature),
            n. = length(Temperature),
            SE = SD/sqrt(n.))

write.csv(Max.Seasons,file="MaxSeasons.csv")

Min.Seasons <- Minimum%>%
  filter(Temperature !="")%>%
  group_by(Season, Placement)%>%
  summarise(Min = min(Temperature),
            Max = max(Temperature),
            Mean = mean(Temperature),
            SD = sd(Temperature),
            n. = length(Temperature),
            SE = SD/sqrt(n.))

write.csv(Min.Seasons,file="MinSeasons.csv")
##Stats time-----------------------------------------------------------------------------------------------
library(lme4)
library(emmeans)
library(effects)
library(car)

#External vs Internal-----------------------------------------------------------------------

#Maximum temperature  
Ambient.Max <- lmer(Temperature~ Placement*Season + Size +
                          (1|Colony/ChamberID) +(1|Date), 
                    control = lmerControl(optimizer ="Nelder_Mead"),
                        data = Maximum)

plot(Ambient.Max)
hist(resid(Ambient.Max))

anova(Ambient.Max)
summary(Ambient.Max) 
Anova(Ambient.Max,Type = "III")


#Post-hoc tests and plots
emmeans(Ambient.Max, pairwise ~ Placement|Season)
emmip(Ambient.Max, Placement~Season)


emmeans(Ambient.Max, pairwise ~ Season|Placement)
emmip(Ambient.Max, Season~Placement)

emmeans(Ambient.Max, pairwise ~ Season)

plot(effect("Placement*Season", Ambient.Max),
     main = "",
     xlab = "",
     ylab = "",
     axes=list(y=list(cex = 1.4),
               x=list(cex = 1.4)))

Max.output <- read_csv(here("Maximum output.csv"))%>%
  mutate(Season = fct_relevel(Season, 
                              "Spring", "Summer", "Autumn", 
                              "Winter"))

yla.Max <- expression(paste("Maximum temperature ", differences ^o, "C"))

ggplot(data=Max.output, aes(x=Season, y=Difference, colour = Placement))+
  geom_line()+
  geom_point(size = 2, position = position_dodge(width = .5))+
  geom_errorbar(aes(ymin = lower.CL, ymax=upper.CL, width= .5),
                position = position_dodge(width = .5))+
  theme_classic()+
  ylab(yla.Max)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)),
        legend.title = element_text(size = 16),
        legend.text = element_text(size = 14))+
  annotate("text", x = 0.6, y = 1., label = "a)", size =6)


#No Interaction

Ambient.Max <- lmer(Temperature~ Placement+Season + Size +
                      (1|Colony/ChamberID) +(1|Date), 
                    control = lmerControl(optimizer ="Nelder_Mead"),
                    data = Maximum)

plot(Ambient.Max)
hist(resid(Ambient.Max))

anova(Ambient.Max)
summary(Ambient.Max) 
Anova(Ambient.Max,Type = "III")

#Post-hoc tests and plots
emmeans(Ambient.Max, pairwise ~ Placement)



#Minimum temperature
Ambient.Min <- lmer(Temperature~ Placement*Season + Size +
                         (1|Colony/ChamberID) +(1|Date), 
                      control = lmerControl(optimizer ="Nelder_Mead"),
                       data = Minimum)

plot(Ambient.Min)
hist(resid(Ambient.Min))
anova(Ambient.Min)
summary(Ambient.Min)                       
Anova(Ambient.Min, Type = "III")

#Interaction removed
Min.No.interaction <- lmer(Temperature~ Placement + Season + Size +
                        (1|Colony/ChamberID) +(1|Date),
                      data = Minimum)

plot(Min.No.interaction)
hist(resid(Min.No.interaction))


summary(Min.No.interaction)                       
Anova(Min.No.interaction, Type = "III")

emmeans(Min.No.interaction, pairwise ~ Placement, type = "response")
emmeans(Min.No.interaction, pairwise ~ Season, type = "response")

emmip(Min.No.interaction, Placement~Season)

plot(effect("Placement", Min.No.interaction),
     main = "",
     xlab = "",
     ylab = "",
     axes=list(y=list(cex = 1.4),
               x=list(cex = 1.4)))

Min.output <- read_csv(here("Minimum output.csv"))%>%
  mutate(Placement = fct_relevel(Placement, 
                              "Ambient", "Edge", "Intermediate ", 
                              "Centre"))


yla.Min <- expression(paste("Minimum temperature ", differences ^o, "C"))

ggplot(data=Min.output, aes(x=Placement, y=Difference, colour = Placement))+
  geom_line()+
  geom_point(size = 2)+
  geom_errorbar(aes(ymin = lower.CL, ymax=upper.CL, width= .2))+
  theme_classic()+
  ylab(yla.Min)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+
  theme(legend.position = "none") +
  annotate("text", x = 0.6, y = 3.5, label = "b)", size =6)


#  All out put

All.output <- read_csv(here("All output.csv"))%>%
  filter(Placement != "Ambient")%>%
  mutate(Placement = fct_relevel(Placement, 
                                 "Edge", "Intermediate", 
                                 "Centre"),
         Type = fct_relevel(Type,"Minimum", "Maximum"))

library(Hmisc)
library(grid)
library(gridBase)
library(gridExtra)

yla.Min <- expression(paste("Temperature difference ("^o, "C)"))

test <- ggplot(data=All.output, aes(x=Placement, y=Difference, colour = Type))+
  geom_line()+
  geom_point(size = 2)+
  geom_errorbar(aes(ymin = lower.CL, ymax=upper.CL, width= .08))+
  geom_abline(intercept = 0, slope = 0)+
  geom_abline(intercept = -0.6, slope = 0,
              linetype="dashed", size=1)+
  geom_abline(intercept = 0.5, slope = 0,
              linetype="dashed", size=1)+
  theme_classic()+
  ylab(yla.Min)+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=12),
        axis.title.x = element_text(margin = margin(t=10, r=0, b = 0, l=0)),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)),
        legend.title = element_blank(),
        legend.text = element_text(size = 10),
        legend.position = c(0.85, 0.30))+
  annotate("text", x = 2, y = 0.2, label = "Ambient", size =4)+
  annotate("text", x = 0.8, y = 0.8, label = "Upper CI", size =4, fontface = 'italic')+
  annotate("text", x = 0.8, y = -0.3, label = "Lower CI", size =4, fontface = 'italic')

gA <- ggplotGrob(test)

ggsave("Figure1.tiff", grid.arrange(arrangeGrob(gA, nrow=1)), dpi=300, height=8.9, width=11.4, units='cm', compression="lzw") 

#Colony Charachteristics---------------------------------------------------------------------------------------------------
#Remove ambient logger from the data

Max.inside <- Maximum%>%
  filter(Placement != "External")

Min.inside <- Minimum%>%
  filter(Placement != "External")

#Reorganise data to use external temperature as a expanatory variable

Max.Ext <- Maximum%>%
  select(Colony, Date, Placement, Temperature)%>%
  filter(Placement =="External")%>%
  mutate(External = Temperature)%>%
  select(-Placement, -Temperature)
  
Max.inside2 <- left_join(Max.inside, Max.Ext, by = c("Colony", "Date"))  

Min.Ext <- Minimum%>%
  select(Colony, Date, Placement, Temperature)%>%
  filter(Placement =="External")%>%
  mutate(External = Temperature)%>%
  select(-Placement, -Temperature)

Min.inside2 <- left_join(Min.inside, Min.Ext, by = c("Colony", "Date")) 

#Maximum with all interactions.

#three way interaction
Inside.Max <- lmer(Temperature ~ Placement + Depth + Size + External + 
                     External * Size * Placement + External*Depth +
                     (1|Colony/ChamberID) + (1|Date),
                   control = lmerControl(optimizer ="Nelder_Mead"),
                   data = Max.inside2)

plot(Inside.Max)
summary(Inside.Max)                       
Anova(Inside.Max, Type = "III")

#Remove further insignificant interactions

Inside.Max <- lmer(Temperature ~ Placement + Depth + Size*External +  
                     External*Placement + Depth*External +
                     (1|Colony/ChamberID) + (1|Date),
                   control = lmerControl(optimizer ="Nelder_Mead"),
                   data = Max.inside2)

plot(Inside.Max)
anova(Inside.Max)
summary(Inside.Max)                       
Anova(Inside.Max, Type = "III")


Inside.Max <- lmer(Temperature ~ Placement + Depth + Size*External + 
                     External*Placement + Depth*External +
                     (1|Colony/ChamberID) + (1|Date),
                   control = lmerControl(optimizer ="Nelder_Mead"),
                   data = Max.inside2)

plot(Inside.Max)
summary(Inside.Max)                       
Anova(Inside.Max, Type = "III")

Inside.Max <- lmer(Temperature ~ Placement + Depth + Size + External + 
                     Size + External*Placement + Depth*External +
                     (1|Colony/ChamberID) + (1|Date),
                   control = lmerControl(optimizer ="Nelder_Mead"),
                   data = Max.inside2)

plot(Inside.Max)
summary(Inside.Max)                       
Anova(Inside.Max, Type = "III")

emtrends(Inside.Max, pairwise ~ Placement, var="External")

effect("Placement*External", Inside.Max) 

linez = c("grey0", "royalblue4", "chocolate4")
Typz = c(1,2,4)

plot(effect("Placement*External", Inside.Max),
     lines=list(multiline=TRUE, col=linez, lty =Typz, lwd=3),
     confint=list(style="auto", alpha=.2),  #lty="dashed", "smooth"
     lattice=list(key.args=list(x=.60, y=.12, corner=c(0, 0),
                                padding.text=2.25, cex.title = 1.5, cex =1.3)),
     ylim = c(12,38),
     xlim = c(12,20),
     main = "",
     axes=list(y=list(cex = 1.4),
               x=list(cex = 1.4)))

plot(effect("Placement*External", Inside.Max),
     lines=list(multiline=TRUE, col=linez, lty =Typz, lwd=3),
     confint=list(style="auto", alpha=.2),  #lty="dashed", "smooth"
     lattice=list(key.args=list(x=.60, y=.12, corner=c(0, 0),
                                padding.text=2.25, cex.title = 1.5, cex =1.3)),
     ylim = c(12,38),
     xlim = c(12,20),
     main = "",
     axes=list(y=list(cex = 1.4),
               x=list(cex = 1.4)))

ef <- effect(term = "Placement*External", Inside.Max)
ef2 <- as.data.frame(ef)

library(Hmisc)
library(grid)
library(gridBase)
library(gridExtra)
library(ggtext)

yla.Max <- expression(paste("Internal temperature ("^o, "C"))
xla.Max <- expression(paste("Maximum ambient temperature ("^o, "C"))

test <- ggplot(ef2, aes(External, fit, col = Placement))+
  geom_line(size = 1)+
  scale_y_continuous(limits = c(10, 40))+
  geom_ribbon( aes(ymin = lower, ymax = upper, fill = Placement, color = NULL), alpha = .15)+ 
  theme_classic()+
  ylab(yla.Max)+
  xlab(xla.Max)+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=12))+
  theme(legend.position="none")+
  annotate("text", x = 10, y = 40, label = "(a)", size =6)

gA <- ggplotGrob(test)

ggsave("Max.tiff", grid.arrange(arrangeGrob(gA, nrow=1)), dpi=300, height=8.9, width=11.4, units='cm', compression="lzw") 

ef3 <- ef2%>%
  mutate(lower = lower - External,
         upper = upper - External,
         fit = fit - External)

yla.Max.dif <- expression(paste("Internal temperature difference ("^o, "C)"))
xla.Max.dif <- expression(paste("Maximum ambient temperature ("^o, "C)"))

test <- ggplot(ef3, aes(External, fit, col = Placement))+
  geom_line(aes(linetype=Placement), size = 1)+
  #scale_y_continuous(limits = c(10, 40))+
  geom_ribbon( aes(ymin = lower, ymax = upper, fill = Placement, color = NULL), alpha = .15)+ 
  theme_classic()+
  theme(legend.position=c(.77, .85),
        legend.text = element_text(size = 12),
        legend.title = element_text(size = 12))+
  ylab(yla.Max.dif)+
  xlab(xla.Max.dif)+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=12))+
  annotate("text", x = 10, y = 6.75, label = "(b)", size =6)

gA <- ggplotGrob(test)

ggsave("Figure2b.tiff", grid.arrange(arrangeGrob(gA, nrow=1)), dpi=300, height=11.4, width=8.9, units='cm', compression="lzw") 



emtrends(Inside.Max, pairwise ~ Depth, var="External")


plot(effect("Depth*External", Inside.Max),
     lattice=list(layout=c(1,5)),
     main = "",
     xlab = "Chamber Depth",
     ylab = "Internal temperature")

plot(effect("Depth*External", Inside.Max),
     lines=list(multiline=TRUE),confint=list(style="auto"),
     main = "",
     xlab = "Chamber Depth",
     ylab = "Internal temperature",
     axes=list(y=list(cex = 2),
               x=list(cex = 2)))

depth <- effect(term = "Depth*External", Inside.Max)
depth22 <- as.data.frame(depth)
     


#Minumum with all interaction
#three way interaction

#Remove outlier
#Min.inside2 <- Min.inside2%>%
 #filter(Size !="102")

Inside.Min <- lmer(Temperature ~  
                      External*Placement + External*Depth + Size * External + 
                     (1|Colony/ChamberID) + (1|Date),
                   control = lmerControl(optimizer ="Nelder_Mead"),
                   data = Min.inside2)

anova(Inside.Min)
plot(Inside.Min)
summary(Inside.Min)                       
Anova(Inside.Min, Type = "III")

emtrends(Inside.Min, pairwise ~ Placement, var = "External")
emtrends(Inside.Min, pairwise ~ Placement*Size, var = "External")
emtrends(Inside.Min, pairwise ~ Placement*External, var = "Size")

emmeans(Inside.Min, pairwise ~ Placement:Size:External, type = "response")

plot(effect("Depth*External", Inside.Min))



plot(effect("External*Placement", Inside.Min),
     lines=list(multiline=TRUE, col=linez, lty =1:3),
     confint=list(style="auto", alpha=.2),  #lty="dashed", "smooth"
     lattice=list(key.args=list(x=.60, y=.12, corner=c(0, 0),
                                padding.text=2.25, cex.title = 1.5, cex =1.3)),
     ylim = c(0,40),
     main = "",
     axes=list(y=list(cex = 1.4),
               x=list(cex = 1.4)))

#Tree-way interaction removed

Inside.Min <- lmer(Temperature ~  Depth+  Size * External + 
                     External*Placement + Depth*External +
                     (1|Colony/ChamberID) + (1|Date),
                   control = lmerControl(optimizer ="Nelder_Mead"),
                   data = Min.inside2)

plot(Inside.Min)
summary(Inside.Min)                       
Anova(Inside.Min, Type = "III")

plot(effect("External*Placement", Inside.Min),
     lines=list(multiline=TRUE, col=linez, lty =1:3),
     confint=list(style="auto", alpha=.2),  #lty="dashed", "smooth"
     lattice=list(key.args=list(x=.60, y=.12, corner=c(0, 0),
                                padding.text=2.25, cex.title = 1.5, cex =1.3)),
     main = "",
     axes=list(y=list(cex = 1.4),
               x=list(cex = 1.4)))

ef <- effect(term = "External*Placement", Inside.Min)
ef2 <- as.data.frame(ef)

ef3 <- ef2%>%
  mutate(lower = lower - External,
         upper = upper - External,
         fit = fit - External)

xla.Min <- expression(paste("Minimum ambient temperature ("^o, "C)"))

test <- ggplot(ef3, aes(External, fit, col = Placement))+
  geom_line(aes(linetype=Placement), size = 1)+
  geom_ribbon( aes(ymin = lower, ymax = upper, fill = Placement, color = NULL), alpha = .15)+ 
  theme_classic()+
  theme(legend.position="none")+
  ylab(yla.Max.dif)+
  xlab(xla.Min)+
  theme(axis.text=element_text(size=11),
        axis.title=element_text(size=12))+
  annotate("text", x = 10, y = 6.75, label = "(a)", size =6)

gA <- ggplotGrob(test)

ggsave("Figure3a.tiff", grid.arrange(arrangeGrob(gA, nrow=1)), dpi=300, height=11.4, width=8.9, units='cm', compression="lzw") 








plot(effect("Depth*External", Inside.Min),
     lattice=list(layout=c(1,5)),
     main = "",
     xlab = "Chamber Depth",
     ylab = "Internal temperature")

plot(effect("Depth*External", Inside.Min),
     lines=list(multiline=TRUE),confint=list(style="auto"),
     main = "",
     xlab = "Chamber Depth",
     ylab = "Internal temperature",
     ylim = c(0,35),
     axes=list(y=list(cex = 2),
               x=list(cex = 2)))

emtrends(Inside.Min, pairwise ~ Placement, var = "External")

depth <- effect(term = "Depth*External", Inside.Min)
depth22 <- as.data.frame(depth)

gA <- ggplotGrob(test)

ggsave("Figure3a.tiff", grid.arrange(arrangeGrob(gA, nrow=1)), dpi=300, height=11.4, width=8.9, units='cm', compression="lzw") 


plot(effect("Size*External", Inside.Min),
     lines=list(multiline=TRUE),confint=list(style="auto"),
     main = "",
     xlab = "Colony size (number of chambers)",
     ylab = "Internal temperature",
     axes=list(y=list(cex = 2),
          x=list(cex = 2)))

size <- effect(term = "Size*External", Inside.Min)
size2 <- as.data.frame(size)

cor.test(Min.inside2$Size, Min.inside2$External)

emtrends(Inside.Min, pairwise ~ Size, var = "External")

emmeans(Inside.Min, pairwise ~ Size|External)
emmeans(Inside.Min, pairwise ~ Size:External, type = "response")

#Compare interclass correlations nad repeatabilities using ther rptR package
library(rptR)

rephp <- rpt(Temperature ~ Size + (1|Colony), grname = c("Colony","Fixed"), data = Max.inside, 
             datatype = "Gaussian", nboot = 1000, npermut = 0, adjusted=FALSE)


rephp1 <- rpt(Temperature ~ Size + (1|Date), grname = c("Date","Fixed"), data = Max.inside, 
              datatype = "Gaussian", nboot = 1000, npermut = 0, adjusted=FALSE)

rephp
rephp1
