rm(list=ls())

library(tidyverse)
library(here)

#Read in temperature data
Summer <- read_csv(here("Summer_MaxTemps_Average.csv"))
Winter <- read_csv(here("Winter_MinTemp_Average.csv"))

unique(Summer$ColonyNumber) #five colonies
unique(Winter$ColonyNumber) #seven colonies
#Reading chamber charateristcs 
F.chambers <- read_csv(here("Falcon positions.csv"))

#Descriptive chamber information

tibble(Distance <- F.chambers %>%
         filter(Type == "Falcon")%>%
        summarise(Mean =mean(Edge),
            SD = sd(Edge),
            n. = length(Edge),
            SE = SD/sqrt(n.)))

#Distance from the edge  
#  Mean       SD      n.      se
#   40.7     23.4    23      4.87

tibble(Depth <- F.chambers%>%
         filter(Type == "Falcon")%>%
         summarise(Mean =mean(Depth),
                   SD = sd(Depth),
                   n. = length(Depth),
                   SE = SD/sqrt(n.)))

#Chamber depth  
#  Mean       SD      n.      se
#   15.0      4.55    23     0.948



t.test(Edge~Type, data = F.chambers, paired = TRUE)
t.test(Depth~Type, data = F.chambers, paired = TRUE)

# Summary data

## Summary stats and Plots

# Temperature info

tibble (Summerdesc <- Summer %>%
  group_by(ChamberType)%>%
  summarise(Mean = mean(Temperature),
            SD = sd(Temperature),
            n. = length(Temperature),
            se = SD/sqrt(n.)))

#                     Mean      SD      n.       SE
#Falcon chamber       36.9      2.17    50      0.307
#Weaver               36.3      1.92    50      0.272

tibble (Winterdesc <- Winter %>%
          group_by(ChamberType)%>%
          summarise(Mean = mean(Temperature),
                    SD = sd(Temperature),
                    n. = length(Temperature),
                    se = SD/sqrt(n.)))

#                     Mean      SD      n.       SE
#Falcon chamber       13.9      2.77    30      0.526
#Weaver               14.6      2.88    30      0.526

#summer
yla.Max <- expression(paste("Maximum  ", temperature ^o, "C"))

ggplot(data = Summer, aes(x=ChamberType, y=Temperature, color = ChamberType))+ 
  geom_boxplot()+
  ggtitle("")+
  geom_point(data=Summer,aes(ChamberType,Temperature,color=ChamberType),position=position_jitter(width =.15))+
  theme_classic()+
  ylab(yla.Max)+
  xlab("")+
  theme(axis.text=element_text(size=18),
        axis.title=element_text(size=18))+
  theme(legend.position = "none")+
  annotate("text", x = .5, y = 41, label = "b)", size =6)

yla.Min <- expression(paste("Minimum ", temperature ^o, "C"))
 
ggplot(data = Winter, aes(x=ChamberType, y=Temperature, color = ChamberType))+ 
  geom_boxplot()+
  ggtitle("")+
  geom_point(data=Winter,aes(ChamberType,Temperature,color=ChamberType),position=position_jitter(width =.15))+
  theme_classic()+
  ylab(yla.Min)+
  xlab("")+
  theme(axis.text=element_text(size=18),
        axis.title=element_text(size=18))+
  theme(legend.position = "none")+
  annotate("text", x = .5, y = 20, label = "a)", size =6)

##Stats time-----------------------------------------------------------------------------------------------
library(lme4)
library(emmeans)
library(effects)
library(car)

#Summer

# singular fits were occuring if chamber ID was fitted as a random effect or if  colony size was added as 
# a response variable  
Max.temp <-  lmer(Temperature ~ ChamberType +  (1|ColonyNumber), data = Summer)

plot(Max.temp)
summary(Max.temp)
anova(Max.temp)
Anova(Max.temp)

emmeans(Max.temp, pairwise ~ ChamberType)

Min.temp <-  lmer(Temperature ~ ChamberType + (1|ColonyNumber), data = Winter)

plot(Min.temp)
summary(Min.temp)
Anova(Min.temp)

emmeans(Min.temp, pairwise ~ ChamberType)

#Messing around with figures

Colony.info <- read_csv(here("Colony info.csv"))%>%
  filter(Placement !="External")%>%
  select("Distance","Depth")%>%
  rename(Edge = Distance)%>%
  add_column(Type = "Weaver")

Chamber.data <- F.chambers%>%
  select("Type","Edge","Depth")%>%
  filter(Type =="Falcon")
  
Chamber.data <- bind_rows(Chamber.data, Colony.info)%>%
  filter(Edge <= 200)

ylabel<- expression(paste("Depth (cm) "))
xlabel<- expression(paste("Distance from the edge (cm) "))

ggplot(data = Chamber.data, aes(x=Edge, y=Depth, colour = Type))+ 
  geom_point(size =2.5)+
  scale_shape_manual(values = c(19,1))+
  geom_smooth(method=lm, se=FALSE,    
              fullrange=TRUE)+
  theme_classic()+
  ylab(ylabel)+
  xlab(xlabel)+
  theme(legend.position=c(.88, .85),
        legend.text = element_text(size = 16),
        legend.title = element_text(size = 18))+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18))+
  labs(color='Chamber') 

ggplot(data = Chamber.data, aes(x=Edge, y=Depth, colour = Type))+ 
  geom_point(size =2.5)+
  scale_shape_manual(values = c(19,1))+
  geom_smooth(method=lm, se=TRUE,    
              fullrange=TRUE)+
  theme_classic()+
  ylab(ylabel)+
  xlab(xlabel)+
  theme(legend.position=c(.88, .85),
        legend.text = element_text(size = 16),
        legend.title = element_text(size = 18))+
  theme(axis.text=element_text(size=16),
      axis.title=element_text(size=18))+
  labs(color='Chamber') 
  
